@@ -1,7 +1,16 @@
-from typing import Dict, Any
+from typing import Dict, Any, Optional, Callable
+from itertools import zip_longest
 
 import tensorflow as tf
 from tensorflow.keras.layers import Layer, Dense, BatchNormalization, InputSpec
+from official.modeling import activations
+
+
+def get_activation(activation_string: str) -> Callable:
+    if activation_string == "gelu":
+        return activations.gelu
+    else:
+        return tf.keras.activations.get(activation_string)
 
 
 class MLPLayer(Layer):
@@ -10,7 +19,11 @@ class MLPLayer(Layer):
         num_layers: int,
         hidden_size: int = 256,
         output_size: int = 1,
-        activation: str = "tanh",
+        activation: str = "relu",
+        last_activation: Optional[str] = None,
+        batch_normal: bool = True,
+        momentum: float = 0.9,
+        epsilon: float = 1e-5,
         name: str = "mlp",
         **kwargs
     ) -> None:
@@ -19,6 +32,10 @@ class MLPLayer(Layer):
         self.hidden_size = hidden_size
         self.output_size = output_size
         self.activation = activation
+        self.last_activation = last_activation or activation
+        self.batch_normal = batch_normal
+        self.momentum = momentum
+        self.epsilon = epsilon
         self.input_spec = InputSpec(min_ndim=2)
 
         self.dense_layers = []
@@ -27,11 +44,20 @@ class MLPLayer(Layer):
             if i == num_layers - 1:
                 self.dense_layers.append(Dense(output_size, name="dense-%d" % i))
             else:
-                _activation = activation if i == num_layers - 2 else "relu"
-                self.dense_layers.append(
-                    Dense(hidden_size, activation=_activation, name="dense-%d" % i)
+                _activation = (
+                    self.last_activation if i == num_layers - 2 else self.activation
                 )
-                self.batchnorm_layers.append(BatchNormalization())
+                self.dense_layers.append(
+                    Dense(
+                        hidden_size,
+                        activation=get_activation(_activation),
+                        name="dense-%d" % i,
+                    )
+                )
+                if self.batch_normal:
+                    self.batchnorm_layers.append(
+                        BatchNormalization(axis=-1, momentum=momentum, epsilon=epsilon)
+                    )
 
     def build(self, input_shape: tf.TensorShape) -> None:
         last_dim = input_shape[-1]
@@ -40,8 +66,12 @@ class MLPLayer(Layer):
 
     def call(self, inputs: tf.Tensor) -> tf.Tensor:
         outputs = inputs
-        for dense, batchnorm in zip(self.dense_layers[:-1], self.batchnorm_layers):
-            outputs = batchnorm(dense(outputs))
+        for dense, batchnorm in zip_longest(
+            self.dense_layers[:-1], self.batchnorm_layers
+        ):
+            outputs = dense(outputs)
+            if batchnorm is not None:
+                outputs = batchnorm(outputs)
         return self.dense_layers[-1](outputs)
 
     def compute_output_shape(self, input_shape: tf.TensorShape) -> tf.TensorShape:
@@ -59,6 +89,9 @@ class MLPLayer(Layer):
             "hidden_size": self.hidden_size,
             "output_size": self.output_size,
             "activation": self.activation,
+            "last_activation": self.last_activation,
+            "momentum": self.momentum,
+            "epsilon": self.epsilon,
         }
         base_config = super().get_config()
         return dict(**base_config, **config)
